@@ -3,6 +3,7 @@ package #1.#x;
 import paraselene.*;
 import paraselene.supervisor.*;
 import java.io.*;
+import paraselene.dyna.*;
 
 /**
  * CSS出力。
@@ -92,5 +93,7 @@ public class Css extends #1.SuperPage implements Downloadable {
 			throw new PageException( e );
 		}
 	}
+
+	public NameDefine[] inspectName( Page page, String ... exclude ){ return null;}
 }
 
