@@ -5,6 +5,7 @@ import paraselene.supervisor.*;
 import paraselene.ajax.*;
 import paraselene.tag.*;
 import paraselene.tag.form.*;
+import paraselene.dyna.*;
 
 /**
  * AJAX の Form通信。
@@ -104,5 +105,6 @@ public class FormJson extends #1.SuperPage {
 		script.setValueString( buf.toString() );
 		return this;
 	}
+	public NameDefine[] inspectName( Page page, String ... exclude ){ return null;}
 }
 
