@@ -120,7 +120,7 @@ public class Color extends PlainText implements AttributeValuable, CSSValuable {
 	}
 
 	/**
-	 * 色の設定。全てのパラメータは下位１バイトのみ取り出して使用する。
+	 * 色の設定。全てのパラメータは下位１バイトのみ取り出して使用します。
 	 * @param r 赤(0x00 ～ 0xff)。負数の場合、transparent となります。
 	 * @param g 緑(0x00 ～ 0xff)。負数の場合、transparent となります。
 	 * @param b 青(0x00 ～ 0xff)。負数の場合、transparent となります。
@@ -161,6 +161,59 @@ public class Color extends PlainText implements AttributeValuable, CSSValuable {
 	public int getBlue() {
 		return blue;
 	}
+
+	private static int unsigned_fix( int v ) {
+		if ( v < 0 )	return 0;
+		if ( v > 255 )	return 255;
+		return v;
+	}
+
+	private static int signed_fix( int v ) {
+		if ( v < -128 )	return -128;
+		if ( v > 127 )	return 127;
+		return v;
+	}
+
+	/**
+	 * YUVの取得。
+	 * @return YUV変換した値。
+	 */
+	public YUV getYUV() {
+		double[]	s = new double[] { red, green, blue };
+		double[]	d = new double[] {
+			0.299 * s[0] + 0.587 * s[1] + 0.114 * s[2],
+			-0.169 * s[0] - 0.331 * s[1] + 0.5 * s[2],
+			0.5 * s[0] - 0.419 * s[1] - 0.081 * s[2]
+		};
+		YUV	yuv = new YUV( unsigned_fix( (int)d[0] ), signed_fix( (int)d[1] ), signed_fix( (int)d[2] ) );
+		return yuv;
+	}
+
+	/**
+	 * コンストラクタ。
+	 * 全てのパラメータは下位１バイトのみ取り出して使用します。
+	 * @param yuv YUV。
+	 */
+	public Color( YUV yuv ) {
+		setColor( yuv );
+	}
+
+	/**
+	 * 色の設定。
+	 * 全てのパラメータは下位１バイトのみ取り出して使用します。
+	 * @param yuv YUV。
+	 */
+	public void setColor( YUV yuv ) {
+		double[]	s = new double[] {
+			unsigned_fix( yuv.y) , signed_fix( yuv.u ), signed_fix( yuv.v )
+		};
+		double[]	d = new double[] {
+			s[0] + 1.402 * s[2],
+			s[0] - 0.344 * s[1] - 0.714 * s[2],
+			s[0] + 1.772 * s[1]
+		};
+		setColor( unsigned_fix( (int)d[0] ), unsigned_fix( (int)d[1] ), unsigned_fix( (int)d[2] ) );
+	}
 }
 
 
