@@ -1073,17 +1073,19 @@ public abstract class Page implements Serializable {
 				);
 				Tag	iframe = new Tag( "iframe", false );
 				iframe.setAttribute(
+					new Attribute( "onload", "paraselene_form_comp();" ),
 					new Attribute( "id", AJAX_TARGET_ID ),
 					new Attribute( "name", AJAX_TARGET_ID ),
-					new Attribute( "scrolling", new Text( "no" ) ),
-					new Attribute( "onload", "paraselene_form_comp();" )
+					new Attribute( "scrolling", new Text( "no" ) )
 				);
 				div[1].addHTMLPart( eclipse, iframe );
 				div[1].setAttribute(
 					new Attribute( "id", AJAX_ADD_ID )
 				);
 				body.removeHTMLPart();
-				body.addHTMLPart( div[0], div[1] );
+				body.addHTMLPart( div[0], div[1] /*, Tag.makeScript(
+					"paraselene_add_event(paraselene_get_id('paraseleneDragonsTail'),'load',setTimeout(paraselene_form_comp,2000);"
+				) */ );
 			}
 			else	ajax_f = false;
 		}
