@@ -8,6 +8,7 @@ package paraselene;
 
 import paraselene.supervisor.*;
 import java.io.*;
+import java.net.*;
 import java.util.jar.*;
 
 /**
@@ -17,9 +18,9 @@ public class Version {
 	private Version(){}
 	/**
 	 * Paraseleneのバージョン番号を表す文字列。
-	 * 2.1.1.12
+	 * 2.1.1.15
 	 */
-	public static final String VERSION = "2.1.1.12";
+	public static final String VERSION = "2.1.1.15";
 	private static final String	SITE = " (http://paraselene.sourceforge.jp/)";
 	private static final String	TITLE = "Paraselene " + VERSION + SITE;
 	private static final String[] CLASS_PATH = new String[] {
@@ -82,6 +83,15 @@ public class Version {
 	}
 
 	private static File seekJar() {
+		try {
+			URL	url = Version.class.getResource( "/paraselene/Version.class" );
+			URI	uri = new URI( url.toString().split( "!" )[0].substring( 4 ) );
+			File	file = new File( uri );
+			return file;
+		}
+		catch( Exception e ) {
+			e.printStackTrace();
+		}
 		for ( int i = 0; i < CLASS_PATH.length; i++ ) {
 			File	ret = seekJar( CLASS_PATH[i] );
 			if ( ret != null )	return ret;
