@@ -16,6 +16,7 @@ public class TagData implements Serializable {
 
 	public String	id = "";
 	public String	body = "";
+	public String[]	cmd = null;
 
 	TagData(){}
 	TagData( Tag tag ) {
@@ -26,6 +27,7 @@ public class TagData implements Serializable {
 			tag.getHTMLPart( i ).write( w, HTMLPart.StringMode.BODY );
 		}
 		body = w.toString();
+		cmd = w.getScript();
 	}
 
 	public static TagData[] getTag( Page p ) {
