@@ -113,9 +113,18 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return buf.append( "\n **/\npublic " );
 	}
 
+	private HashMap<String, NameDefine>	define = new HashMap<String, NameDefine>();
+
 	private StringBuilder getMethod( String name, Tag t ) throws TagException {
 		StringBuilder	buf = getCom( name, null, (TagSource)t );
 		String	cls = TagMap.getClassString( t );
+		try {
+			define.put( name, new NameDefine( name, TagMap.getClass( t ) ) );
+		}
+		catch( Exception e ) {
+			e.printStackTrace();
+			System.exit( 1 );
+		}
 		buf = buf.append( cls );
 		FunctionInfo	info = makeFunctionInfo( cls, t.getName(), name );
 		buf = buf.append( toName( info ) );
@@ -136,6 +145,9 @@ public class PrePage extends DynamicPage implements OutputNo {
 	private static final String TAG_ARRAY = TagMap.TAG + "[]";
 
 	private StringBuilder getMethod( String name ) throws TagException {
+		if ( define.get( name ) == null ) {
+			define.put( name, new NameDefine( name ) );
+		}
 		Tag[]	t = getAllTag( name );
 		ArrayList<Tag>	left_tag = new ArrayList<Tag>();
 		for ( int i = 0; i < t.length; i++ ) {
@@ -208,6 +220,26 @@ public class PrePage extends DynamicPage implements OutputNo {
 					}
 					catch( Exception e ) {}
 				}
+
+				buf = buf.append( "/**\n * name 属性の検証。\n * @param page 検証するページ\n * @param exclude 検証から除外する name。\n * @return エラーとなった name。\n */\n" );
+				buf = buf.append( "public NameDefine[] inspectName(Page page,String ... exclude){\nreturn DynamicPage.inspectName(page,new NameDefine[]{\n" );
+				String	sep = "";
+				for ( String key : define.keySet() ) {
+					buf = buf.append( sep );
+					NameDefine	def = define.get( key );
+					buf = buf.append( "new NameDefine(" );
+					buf = buf.append( Make.escape( def.getName() ) );
+					Class<?>	cls = def.getDefineClass();
+					if ( cls != null ) {
+						buf = buf.append( "," );
+						buf = buf.append( cls.getName() );
+						buf = buf.append( ".class" );
+					}
+					buf = buf.append( ")" );
+					sep = ",\n";
+				}
+				buf = buf.append( "},exclude);\n}\n" );
+
 				return buf.toString();
 			}
 		case 33:
