@@ -11,5 +11,9 @@ public class TagException extends Exception {
 	TagException( String s) {
 		super( s );
 	}
+
+	TagException( Throwable e ) {
+		super( e );
+	}
 }
 
