@@ -670,6 +670,7 @@ public abstract class Supervisor extends HttpServlet {
 				try {
 					if ( date.compareTo( new HTTPDate( mod[0] ) ) <= 0 ) {
 						res.setStatus( 304 );
+						res.setContentType( mime );
 						data.hist.get( next_page.getHistoryKey() ).add( next_page );
 						return;
 					}
@@ -695,18 +696,26 @@ public abstract class Supervisor extends HttpServlet {
 				return;
 			}
 			if ( out_ret[1] instanceof Downloadable ) {
+				//res.addHeader( "Transfer-Encoding", "chunked" );
 				Downloadable	dl = (Downloadable)out_ret[1];
 				OutputStream	out = new BufferedOutputStream( res.getOutputStream() );
 				BufferedInputStream		in = new BufferedInputStream( dl.getInputStream() );
 				try{
+					//byte[]	crlf = new byte[] { 0x0d, 0x0a };
 					byte[]	buf = new byte[4096];
 					while( true ) {
 						int	size = in.read( buf );
 						if ( size <= 0 )	break;
+						//out.write( Integer.toString( size, 16 ).getBytes() );
+						//out.write( crlf );
 						out.write( buf, 0, size );
+						//out.write( crlf );
 						if ( size < buf.length )	break;
 						holder.req.getSession( false );
 					}
+					//out.write( Integer.toString( 0, 16 ).getBytes() );
+					//out.write( crlf );
+					//out.write( crlf );
 					in.close();
 					out.flush();
 				}
