@@ -28,8 +28,10 @@ public class Anchor extends Tag {
 	}
 
 	public void write( PrintWriter w, StringMode mode ) {
-		setHTTPAjaxHandler( "href", "onclick", "return paraselene_agency_a(this,'%s');" );
+		//setHTTPAjaxHandler( "href", "onclick", "return paraselene_agency_a(this,'%s');" );
+		makeID();
 		super.write( w, mode );
+		setHttpAjaxEventListener( w, mode, "paraselene_a_handler(%s,%s)" );
 
 /*
 		Page	page = getAssignedPage();
