@@ -13,6 +13,7 @@ import java.math.*;
 import paraselene.*;
 import paraselene.tag.form.*;
 import paraselene.supervisor.*;
+import paraselene.ajax.data.*;
 
 /**
  * HTML汎用タグ。
@@ -1142,7 +1143,7 @@ public class Tag extends HTMLPart {
 		return null;
 	}
 
-	protected void setAjaxHandler( String triger, String function, Object ... param ) {
+	protected void setButtonAjaxHandler( String triger, String function, Object ... param ) {
 		Page	page = getAssignedPage();
 		if ( !page.isAjax() )	return;
 		Attribute	attr = getAttribute( triger );
@@ -1157,9 +1158,55 @@ public class Tag extends HTMLPart {
 		URIValue	v = (URIValue)attr.get();
 		if ( v == null )	return;
 		if ( v.isParaselenePagePath() ) {
-			setAjaxHandler( triger, function, getAssignedPage().getUniqueKey() );
+			setButtonAjaxHandler( triger, function, getAssignedPage().getUniqueKey() );
 		}
 	}
 
+	protected void setHttpAjaxEventListener( PrintWriter w, HTMLPart.StringMode mode, String func ) {
+		setButtonAjaxEventListener( w, mode, func, null );
+	}
+
+	protected void setButtonAjaxEventListener( PrintWriter w, HTMLPart.StringMode mode, String func, String param ) {
+		Page	page = getAssignedPage();
+		if ( !page.isAjax() )	return;
+		StringBuilder	buf;
+		if ( param == null ) {
+			if ( !isAjaxEnable() || getAttribute( "target" ) != null )	return;
+			buf = new StringBuilder( "'" );
+			buf = buf.append( page.getUniqueKey() );
+			buf = buf.append( "'" );
+			param = buf.toString();
+		}
+		buf = new StringBuilder( "'" );
+		buf = buf.append( getIDAttribute() );
+		buf = buf.append( "'" );
+		String	id = buf.toString();
+		String	s = String.format( func, id, param );
+		if ( w instanceof JsonWriter ) {
+			JsonWriter	jw = (JsonWriter)w;
+			jw.addScript( s );
+			return;
+		}
+		Tag	tag = makeScript( s );
+		tag.write( w, mode );
+	}
+
+	/**
+	 * JavaScript を安全に記述するための script タグを生成します。
+	 * @param script JavaScript。各引数には改行が挟まれて出力されます。
+	 * @return script タグ。
+	 */
+	public static Tag makeScript( String ... script ) {
+		Tag	tag = new Tag( "script", false );
+		tag.setAttribute( new Attribute( "type", "text/javascript" ) );
+		StringBuilder	buf = new StringBuilder( "<!--//--><![CDATA[//><!--\r\n" );
+		for ( int i = 0; i < script.length; i++ ) {
+			buf = buf.append( script[i] );
+			buf = buf.append( "\r\n" );
+		}
+		buf = buf.append( "//--><!]]>\r\n" );
+		tag.addHTMLPart( new PlainText( buf.toString() ) );
+		return tag;
+	}
 }
 
