@@ -104,9 +104,11 @@ public class Form extends Tag {
 	}
 
 	public void write( PrintWriter w, StringMode mode ) {
-		setHTTPAjaxHandler( "action", "onsubmit", "return paraselene_agency_form(this,'%s');" );
+		//setHTTPAjaxHandler( "action", "onsubmit", "return paraselene_agency_form(this,'%s');" );
 		dummy.setValueString( form_seq.getSeq() );
+		makeID();
 		super.write( w, mode );
+		setHttpAjaxEventListener( w, mode, "paraselene_form_handler(%s,%s)" );
 /*
 		Page	page = getAssignedPage();
 		String	id = getIDAttribute();
